@@ -1,14 +1,14 @@
 use rand::Rng;
 use rnp::{
     PingClientConfig, PingResultProcessorConfig, PingWorkerConfig, PingWorkerSchedulerConfig,
-    RnpCoreConfig, RnpSupportedProtocol,
+    PortRangeList, RnpCoreConfig, RnpSupportedProtocol,
 };
 use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr};
 use std::path::PathBuf;
 use std::time::Duration;
 use structopt::StructOpt;
 
-#[derive(Debug, StructOpt, PartialOrd, PartialEq)]
+#[derive(Debug, StructOpt, PartialEq)]
 #[structopt(name = rnp::RNP_NAME, author = rnp::RNP_AUTHOR, about = rnp::RNP_ABOUT)]
 pub struct RnpCliOptions {
     #[structopt(flatten)]
@@ -21,7 +21,7 @@ pub struct RnpCliOptions {
     quic_options: RnpCliQuicPingOptions,
 }
 
-#[derive(Debug, StructOpt, PartialOrd, PartialEq)]
+#[derive(Debug, StructOpt, PartialEq)]
 pub struct RnpCliCommonOptions {
     pub target: SocketAddr,
 
@@ -41,18 +41,12 @@ pub struct RnpCliCommonOptions {
     )]
     pub source_ip: IpAddr,
 
-    #[structopt(long = "src-port-min", help = "First source port to use in ping.")]
-    pub source_port_min: Option<u16>,
-
-    #[structopt(long = "src-port-max", help = "Last source port to use in ping.")]
-    pub source_port_max: Option<u16>,
-
     #[structopt(
-        long = "src-port",
-        use_delimiter = true,
-        help = "Source port list to use in ping."
+        long = "src-ports",
+        alias = "sp",
+        help = "Source port ranges to rotate in ping. Format: port,start-end. Example: 1024,10000-11000. [alias: --sp]"
     )]
-    pub source_port_list: Option<Vec<u16>>,
+    pub source_ports: Option<PortRangeList>,
 
     #[structopt(short = "n", long = "count", default_value = "4", help = "Ping count.")]
     pub ping_count: u32,
@@ -60,7 +54,7 @@ pub struct RnpCliCommonOptions {
     #[structopt(short = "t", help = "Ping until stopped.")]
     pub ping_until_stopped: bool,
 
-    #[structopt(long = "warmup", default_value = "1", help = "Warm up ping count.")]
+    #[structopt(long = "warmup", default_value = "0", help = "Warm up ping count.")]
     pub warmup_count: u32,
 
     #[structopt(
@@ -98,7 +92,7 @@ pub struct RnpCliCommonOptions {
     pub parallel_ping_count: u32,
 }
 
-#[derive(Debug, StructOpt, PartialOrd, PartialEq)]
+#[derive(Debug, StructOpt, PartialEq)]
 pub struct RnpCliOutputOptions {
     #[structopt(
         short = "q",
@@ -109,19 +103,22 @@ pub struct RnpCliOutputOptions {
 
     #[structopt(
         long = "log-csv",
+        alias = "oc",
         parse(from_os_str),
-        help = "Log ping results a csv file."
+        help = "Log ping results a csv file. [alias: --oc]"
     )]
     pub csv_log_path: Option<PathBuf>,
 
     #[structopt(
         long = "log-json",
+        alias = "oj",
         parse(from_os_str),
-        help = "Log ping results to a json file."
+        help = "Log ping results to a json file. [alias: --oj]"
     )]
     pub json_log_path: Option<PathBuf>,
 
     #[structopt(
+        short = "o",
         long = "log-text",
         parse(from_os_str),
         help = "Log ping results to a text file."
@@ -151,14 +148,17 @@ pub struct RnpCliOutputOptions {
     pub latency_buckets: Option<Vec<f64>>,
 }
 
-#[derive(Debug, StructOpt, PartialOrd, PartialEq)]
+#[derive(Debug, StructOpt, PartialEq)]
 struct RnpCliQuicPingOptions {
-    #[structopt(long, help = "Specify the server name in the pings, such as QUIC.")]
+    #[structopt(
+        long,
+        help = "Specify the server name in the QUIC pings. Example: localhost."
+    )]
     pub server_name: Option<String>,
 
     #[structopt(
         long,
-        help = "Enable key logger in TLS for helping packet capture.\nPlease note that it might cause RTT to be larger than the real one, because logging key will also take time."
+        help = "Enable key logger in TLS for helping packet capture.\nPlease note that it might cause RTT to be slightly larger than the real one, because logging key will also take time."
     )]
     pub log_tls_key: bool,
 
@@ -222,12 +222,7 @@ impl RnpCliOptions {
                 },
             },
             worker_scheduler_config: PingWorkerSchedulerConfig {
-                source_port_min: self.common_options.source_port_min.unwrap(),
-                source_port_max: self.common_options.source_port_max.unwrap(),
-                source_port_list: match &self.common_options.source_port_list {
-                    Some(port_list) => Some(port_list.clone()),
-                    None => None,
-                },
+                source_ports: self.common_options.source_ports.as_ref().unwrap().clone(),
                 ping_count: None,
                 warmup_count: self.common_options.warmup_count,
                 parallel_ping_count: self.common_options.parallel_ping_count,
@@ -271,17 +266,12 @@ impl RnpCliCommonOptions {
             }
         }
 
-        if self.source_port_min.is_none() {
-            self.source_port_min = Some(rand::thread_rng().gen_range(10000..30000));
-        }
-
-        if self.source_port_max.is_none() {
-            self.source_port_max = Some(self.source_port_min.unwrap() + 10000);
-        }
-
-        if self.source_port_min > self.source_port_max {
-            tracing::warn!("Min source port is larger than max, swapping to fix.");
-            std::mem::swap(&mut self.source_port_min, &mut self.source_port_max);
+        if self.source_ports.is_none() {
+            let range_start = rand::thread_rng().gen_range(10000..30000);
+            let range_end = range_start + 2000;
+            self.source_ports = Some(PortRangeList {
+                ranges: vec![(range_start..=range_end)],
+            });
         }
 
         if !self.ping_until_stopped && self.ping_count < 1 {
@@ -289,18 +279,18 @@ impl RnpCliCommonOptions {
             self.ping_count = 1;
         }
 
-        let available_source_port_count = match &self.source_port_list {
-            Some(port_list) => port_list.len() as u32,
-            None => self.source_port_max.unwrap() as u32 - self.source_port_min.unwrap() as u32 + 1,
-        };
-
-        if self.parallel_ping_count > available_source_port_count {
+        let available_source_port_count = self
+            .source_ports
+            .as_ref()
+            .unwrap()
+            .calculate_total_port_count();
+        if self.parallel_ping_count > available_source_port_count as u32 {
             tracing::warn!(
                 "Parallel ping count ({}) is larger than available source port count ({}), to avoid port conflict reducing parallel ping count down to the same as available source port count.",
                 self.parallel_ping_count,
                 available_source_port_count);
 
-            self.parallel_ping_count = available_source_port_count;
+            self.parallel_ping_count = available_source_port_count as u32;
         }
 
         if self.parallel_ping_count < 1 {
@@ -329,12 +319,10 @@ mod tests {
                     target: "10.0.0.1:443".parse().unwrap(),
                     protocol: RnpSupportedProtocol::TCP,
                     source_ip: "0.0.0.0".parse().unwrap(),
-                    source_port_min: None,
-                    source_port_max: None,
-                    source_port_list: None,
+                    source_ports: None,
                     ping_count: 4,
                     ping_until_stopped: false,
-                    warmup_count: 1,
+                    warmup_count: 0,
                     wait_timeout_in_ms: 2000,
                     ping_interval_in_ms: 1000,
                     time_to_live: None,
@@ -369,12 +357,12 @@ mod tests {
                     target: "10.0.0.1:443".parse().unwrap(),
                     protocol: RnpSupportedProtocol::TCP,
                     source_ip: "10.0.0.2".parse().unwrap(),
-                    source_port_min: None,
-                    source_port_max: None,
-                    source_port_list: None,
+                    source_ports: Some(PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    }),
                     ping_count: 10,
                     ping_until_stopped: true,
-                    warmup_count: 1,
+                    warmup_count: 0,
                     wait_timeout_in_ms: 1000,
                     ping_interval_in_ms: 1500,
                     time_to_live: None,
@@ -389,9 +377,9 @@ mod tests {
                 },
                 output_options: RnpCliOutputOptions {
                     no_console_log: true,
-                    csv_log_path: None,
-                    json_log_path: None,
-                    text_log_path: None,
+                    csv_log_path: Some(PathBuf::from("log.csv")),
+                    json_log_path: Some(PathBuf::from("log.json")),
+                    text_log_path: Some(PathBuf::from("log.txt")),
                     show_result_scatter: true,
                     show_latency_scatter: true,
                     latency_buckets: Some(vec![0.1, 0.5, 1.0, 10.0]),
@@ -404,6 +392,8 @@ mod tests {
                 "tcp",
                 "-s",
                 "10.0.0.2",
+                "--sp",
+                "1024-2048,3096,3097",
                 "-n",
                 "10",
                 "-t",
@@ -415,6 +405,12 @@ mod tests {
                 "-p",
                 "10",
                 "-q",
+                "--oc",
+                "log.csv",
+                "--oj",
+                "log.json",
+                "-o",
+                "log.txt",
                 "-r",
                 "-l",
                 "-b",
@@ -431,9 +427,9 @@ mod tests {
                     target: "10.0.0.1:443".parse().unwrap(),
                     protocol: RnpSupportedProtocol::QUIC,
                     source_ip: "10.0.0.2".parse().unwrap(),
-                    source_port_min: Some(1024),
-                    source_port_max: Some(2048),
-                    source_port_list: Some(vec![1024, 1025, 1026]),
+                    source_ports: Some(PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    }),
                     ping_count: 10,
                     ping_until_stopped: false,
                     warmup_count: 3,
@@ -466,12 +462,8 @@ mod tests {
                 "quic",
                 "--src-ip",
                 "10.0.0.2",
-                "--src-port-min",
-                "1024",
-                "--src-port-max",
-                "2048",
-                "--src-port",
-                "1024,1025,1026",
+                "--src-ports",
+                "1024-2048,3096,3097",
                 "--count",
                 "10",
                 "--warmup",
@@ -526,9 +518,9 @@ mod tests {
                     },
                 },
                 worker_scheduler_config: PingWorkerSchedulerConfig {
-                    source_port_min: 1024,
-                    source_port_max: 2047,
-                    source_port_list: Some(vec![1024, 1025, 1026]),
+                    source_ports: PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    },
                     ping_count: Some(4),
                     warmup_count: 1,
                     parallel_ping_count: 1,
@@ -553,9 +545,9 @@ mod tests {
                     ping_until_stopped: false,
                     warmup_count: 1,
                     source_ip: "10.0.0.2".parse().unwrap(),
-                    source_port_min: Some(1024),
-                    source_port_max: Some(2047),
-                    source_port_list: Some(vec![1024, 1025, 1026]),
+                    source_ports: Some(PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    }),
                     wait_timeout_in_ms: 1000,
                     ping_interval_in_ms: 1500,
                     time_to_live: Some(128),
@@ -599,9 +591,9 @@ mod tests {
                     },
                 },
                 worker_scheduler_config: PingWorkerSchedulerConfig {
-                    source_port_min: 1024,
-                    source_port_max: 2047,
-                    source_port_list: Some(vec![1024, 1025, 1026]),
+                    source_ports: PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    },
                     ping_count: None,
                     warmup_count: 3,
                     parallel_ping_count: 1,
@@ -626,9 +618,9 @@ mod tests {
                     ping_until_stopped: true,
                     warmup_count: 3,
                     source_ip: "10.0.0.2".parse().unwrap(),
-                    source_port_min: Some(1024),
-                    source_port_max: Some(2047),
-                    source_port_list: Some(vec![1024, 1025, 1026]),
+                    source_ports: Some(PortRangeList {
+                        ranges: vec![(1024..=2048), (3096..=3096), (3097..=3097)]
+                    }),
                     wait_timeout_in_ms: 2000,
                     ping_interval_in_ms: 1500,
                     time_to_live: Some(128),
@@ -660,27 +652,32 @@ mod tests {
         let mut opts = RnpCliOptions::from_iter(&["rnp.exe", "10.0.0.1:443"]);
         opts.prepare_to_use();
 
-        assert!(opts.common_options.source_port_min.is_some());
-        assert!(opts.common_options.source_port_max.is_some());
+        assert!(opts.common_options.source_ports.is_some());
         assert_eq!(
-            10000,
-            opts.common_options.source_port_max.unwrap()
-                - opts.common_options.source_port_min.unwrap()
+            1,
+            opts.common_options
+                .source_ports
+                .as_ref()
+                .unwrap()
+                .ranges
+                .len()
+        );
+        assert_eq!(
+            2000,
+            opts.common_options.source_ports.as_ref().unwrap().ranges[0].end()
+                - opts.common_options.source_ports.as_ref().unwrap().ranges[0].start()
         );
     }
 
     #[test]
     fn invalid_options_for_ipv4_should_be_fixed() {
         let mut opts = RnpCliOptions::from_iter(&["rnp.exe", "10.0.0.1:443"]);
-        opts.common_options.source_port_min = Some(2048);
-        opts.common_options.source_port_max = Some(1024);
+        opts.common_options.source_ports = None;
         opts.common_options.ping_count = 0;
         opts.common_options.parallel_ping_count = 0;
         opts.output_options.latency_buckets = Some(vec![0.0]);
         opts.prepare_to_use();
 
-        assert_eq!(1024, opts.common_options.source_port_min.unwrap());
-        assert_eq!(2048, opts.common_options.source_port_max.unwrap());
         assert_eq!(1, opts.common_options.ping_count);
         assert_eq!(1, opts.common_options.parallel_ping_count);
         assert_eq!(
@@ -690,15 +687,16 @@ mod tests {
             opts.output_options.latency_buckets
         );
 
-        opts.common_options.source_port_min = Some(1024);
-        opts.common_options.source_port_max = Some(1047);
+        opts.common_options.source_ports = Some(PortRangeList {
+            ranges: vec![(1024..=1047)],
+        });
         opts.common_options.parallel_ping_count = 100;
         opts.prepare_to_use();
         assert_eq!(24, opts.common_options.parallel_ping_count);
 
-        opts.common_options.source_port_min = None;
-        opts.common_options.source_port_max = None;
-        opts.common_options.source_port_list = Some(vec![1024, 1025, 1026]);
+        opts.common_options.source_ports = Some(PortRangeList {
+            ranges: vec![(1024..=1024), (1025..=1025), (1026..=1026)],
+        });
         opts.common_options.parallel_ping_count = 100;
         opts.prepare_to_use();
         assert_eq!(3, opts.common_options.parallel_ping_count);
