@@ -1,4 +1,4 @@
-use crate::ping_clients::ping_client::PingClient;
+use crate::*;
 use pretty_assertions::assert_eq;
 use std::net::SocketAddr;
 use std::time::Duration;
@@ -19,32 +19,41 @@ pub struct ExpectedPingClientTestResults {
 
 pub async fn run_ping_client_tests(
     ping_client: &mut Box<dyn PingClient + Send + Sync>,
+    mock_server_addr: &SocketAddr,
     expected_results: &ExpectedPingClientTestResults,
 ) {
-    // TODO: This is failing on Linux and MAC, need to figure out why.
-    if cfg!(windows) {
-        ping_client_should_work_when_pinging_good_host(ping_client, expected_results).await;
+    if ping_client.protocol() != "QUIC" {
+        ping_client_should_work_when_pinging_good_host(ping_client, mock_server_addr, expected_results).await;
     }
 
     ping_client_should_fail_when_pinging_non_existing_host(ping_client, expected_results).await;
     ping_client_should_fail_when_pinging_non_existing_port(ping_client, expected_results).await;
     ping_client_should_fail_when_binding_invalid_source_ip(ping_client, expected_results).await;
-    ping_client_should_fail_when_binding_unavailable_source_port(ping_client, expected_results).await;
+
+    if ping_client.protocol() != "QUIC" {
+        ping_client_should_fail_when_binding_unavailable_source_port(ping_client, mock_server_addr, expected_results).await;
+    }
 }
 
 async fn ping_client_should_work_when_pinging_good_host(
     ping_client: &mut Box<dyn PingClient + Send + Sync>,
+    mock_server_addr: &SocketAddr,
     expected_results: &ExpectedPingClientTestResults,
 ) {
+    let target = mock_server_addr.clone();
+    if target.port() == 0 {
+        return;
+    }
+
     let source = "0.0.0.0:0".parse::<SocketAddr>().unwrap();
-    let target = "127.0.0.1:3389".parse::<SocketAddr>().unwrap();
     ping_client_result_should_be_expected(
         ping_client,
         &source,
         &target,
         expected_results.timeout_min_time,
         &ExpectedTestCaseResult::Ok,
-    ).await;
+    )
+    .await;
 }
 
 async fn ping_client_should_fail_when_pinging_non_existing_host(
@@ -59,7 +68,8 @@ async fn ping_client_should_fail_when_pinging_non_existing_host(
         &target,
         expected_results.timeout_min_time,
         &expected_results.ping_non_existing_host_result,
-    ).await;
+    )
+    .await;
 }
 
 async fn ping_client_should_fail_when_pinging_non_existing_port(
@@ -74,7 +84,8 @@ async fn ping_client_should_fail_when_pinging_non_existing_port(
         &target,
         expected_results.timeout_min_time,
         &expected_results.ping_non_existing_port_result,
-    ).await;
+    )
+    .await;
 }
 
 async fn ping_client_should_fail_when_binding_invalid_source_ip(
@@ -89,14 +100,16 @@ async fn ping_client_should_fail_when_binding_invalid_source_ip(
         &target,
         expected_results.timeout_min_time,
         &expected_results.binding_invalid_source_ip_result,
-    ).await;
+    )
+    .await;
 }
 
 async fn ping_client_should_fail_when_binding_unavailable_source_port(
     ping_client: &mut Box<dyn PingClient + Send + Sync>,
+    mock_server_addr: &SocketAddr,
     expected_results: &ExpectedPingClientTestResults,
 ) {
-    let source = "127.0.0.1:11337".parse::<SocketAddr>().unwrap();
+    let source = mock_server_addr.clone();
     let target = "127.0.0.1:56789".parse::<SocketAddr>().unwrap();
     ping_client_result_should_be_expected(
         ping_client,
@@ -104,7 +117,8 @@ async fn ping_client_should_fail_when_binding_unavailable_source_port(
         &target,
         expected_results.timeout_min_time,
         &expected_results.binding_unavailable_source_port_result,
-    ).await;
+    )
+    .await;
 }
 
 async fn ping_client_result_should_be_expected(
@@ -115,6 +129,9 @@ async fn ping_client_result_should_be_expected(
     expected_error: &ExpectedTestCaseResult,
 ) {
     let actual_result = ping_client.ping(source, target).await;
+    let ping_result_string = format!("Ping result: {:?}", actual_result);
+    tracing::info!("{}", ping_result_string);
+
     match expected_error {
         ExpectedTestCaseResult::Ok => {
             assert!(actual_result.is_ok());
