@@ -1,10 +1,9 @@
+use crate::PingResultProcessor;
 use crate::rnp_test_common;
-use crate::ping_result_processors::ping_result_processor::PingResultProcessor;
 
 pub fn run_ping_result_processor_with_test_samples(
     processor: &mut Box<dyn PingResultProcessor + Send + Sync>,
-)
-{
+) {
     let ping_results = rnp_test_common::generate_ping_result_test_samples();
 
     processor.initialize();
@@ -12,4 +11,4 @@ pub fn run_ping_result_processor_with_test_samples(
         processor.process_ping_result(&ping_result);
     }
     processor.rundown();
-}
\ No newline at end of file
+}
