@@ -1,5 +1,4 @@
-use crate::ping_result_processors::ping_result_processor::PingResultProcessor;
-use crate::{rnp_utils, PingResult};
+use crate::*;
 use std::fs::File;
 use std::io::prelude::*;
 use std::path::PathBuf;
@@ -21,6 +20,10 @@ impl PingResultProcessorTextLogger {
 }
 
 impl PingResultProcessor for PingResultProcessorTextLogger {
+    fn name(&self) -> &'static str {
+        "TextLogger"
+    }
+
     fn process_ping_result(&mut self, ping_result: &PingResult) {
         let log_content: String = ping_result.format_as_console_log();
         self.log_file.write(log_content.as_bytes()).expect(&format!(
